(function() {

  function toggleRadioButtons(inputQuery, fieldset) {
    if (inputQuery.length === 0) {
      for (var radio of fieldset.querySelectorAll('input[type="radio"]')) {
        radio.parentElement.hidden = false;
      }
      return;
    }
    // var checkedRadio = fieldset.querySelector('input[type="radio"][checked]');
    var matching = Array.from(fieldset.querySelectorAll('input[type="radio"]'))
      .filter(e => e.value.search(inputQuery) !== -1);
    // Hide all inputs, then show the matching and selected.
    for (var radio of fieldset.querySelectorAll('input[type="radio"]')) {
      radio.parentElement.hidden = true;
    }
    for (var matchingRadio of matching) {
      matchingRadio.parentElement.hidden = false;
    }
  }

  function subscribeToChanges(fieldset) {
    var search = fieldset.querySelector('input[type="search"]');
    var change = (event) => toggleRadioButtons(event.target.value, fieldset);
    search.addEventListener('input', change);
  }

  var renderCurrentlySelected = (info, selectedContainer) => {
    var id = selectedContainer.querySelector('input[type="radio"]').value;
    var name = selectedContainer.querySelector('.form-item__label').innerText;
    var description = selectedContainer.querySelector('.form-item__description').innerText;
    var status = selectedContainer.querySelector('.radio-details--status').innerText;
    var componentType = selectedContainer.querySelector('.radio-details--type').innerText;
    var documentation = selectedContainer.querySelector('.radio-details--documentation').innerHTML;
    var img = selectedContainer.querySelector('img');
    var thumbnailHref = img ? img.src : null;
    info.innerHTML = Drupal.theme('currentlySelectedClComponent', id, name, description, status, componentType, documentation, thumbnailHref);
    info.hidden = false;
  };

  /**
   * Set up options filter
   */
  Drupal.behaviors.optionsFilter = {
    attach: (context, settings) => {
      var fieldsets = once('options-filter', '.cl-components--selector', context);
      for (var fieldset of fieldsets) {
        var search = fieldset.querySelector('input[type="search"]');
        toggleRadioButtons(search.value, fieldset);
        subscribeToChanges(fieldset);
      }
    },
  };

  Drupal.theme.currentlySelectedClComponent = (id, name, description, status, componentType, documentation, thumbnailHref) => {
    const markup = `
      <h5>${Drupal.t('More information about')} "${name}" (${id})</h5>
      <p>${description}</p>
      <div class='image-table--wrapper'>
        <table>
          <tr><th>${Drupal.t('Type')}</th><td>${componentType}</td></tr>
          <tr><th>${Drupal.t('Status')}</th><td>${status}</td></tr>
        </table>
        <div class='currently-selected--image--wrapper${thumbnailHref ? '' : ' currently-selected--image--wrapper__empty'}'>
          ${thumbnailHref ? '<img alt="' + Drupal.t('Thumbnail for component') + '" src="' + thumbnailHref + '" />' : ''}
        </div>
      </div> `;
    return documentation
      ? `${markup}<div class='currently-selected--readme'> ${documentation} </div>`
      : markup;
  };

  /**
   * Render more info about the currently selected component.
   */
  Drupal.behaviors.currentlySelected = {
    attach: (context, settings) => {
      var fieldsets = once('currently-selected', '.cl-components--selector', context);
      for (var fieldset of fieldsets) {
        var info = fieldset.querySelector('.currently-selected');
        info.hidden = true;
        var selected = fieldset.querySelector('input[type="radio"][checked]');
        if (selected) {
          renderCurrentlySelected(info, selected.parentElement);
        }
        var radios = once('radio-change-subscribed', 'input[type="radio"]', fieldset);
        for (radio of radios) {
          radio.addEventListener('change', (event) => {
            if (event.target.checked) {
              renderCurrentlySelected(info, event.target.parentElement);
            }
          });
        }
      }
    },
  };

}());
